@@ -21,7 +21,7 @@ from abc import abstractmethod
 from datetime import datetime
 from enum import unique
 from pathlib import Path
-from typing import Tuple, Union
+from typing import Union
 
 import geopandas as gpd
 import numpy as np
@@ -40,6 +40,7 @@ from eoreader.bands import OpticalBandNames as obn
 from eoreader.bands import to_str
 from eoreader.exceptions import InvalidProductError, InvalidTypeError
 from eoreader.products import OpticalProduct
+from eoreader.reader import Platform
 from eoreader.utils import DATETIME_FMT, EOREADER_NAME
 
 LOGGER = logging.getLogger(EOREADER_NAME)
@@ -102,9 +103,8 @@ class LandsatProduct(OpticalProduct):
         mtd, _ = self.read_mtd()
 
         # Open identifier
-        try:
-            col_nb = mtd.findtext(".//COLLECTION_NUMBER")
-        except TypeError:
+        col_nb = mtd.findtext(".//COLLECTION_NUMBER")
+        if not col_nb:
             raise InvalidProductError("COLLECTION_NUMBER not found in metadata!")
 
         return LandsatCollection.from_value(col_nb)
@@ -117,9 +117,8 @@ class LandsatProduct(OpticalProduct):
         mtd, _ = self.read_mtd()
 
         # Open identifier
-        try:
-            name = mtd.findtext(".//LANDSAT_PRODUCT_ID")
-        except TypeError:
+        name = mtd.findtext(".//LANDSAT_PRODUCT_ID")
+        if not name:
             raise InvalidProductError("LANDSAT_PRODUCT_ID not found in metadata !")
 
         # Collections are not set yet
@@ -238,7 +237,7 @@ class LandsatProduct(OpticalProduct):
     @abstractmethod
     def _set_product_type(self) -> None:
         """Set products type"""
-        raise NotImplementedError("This method should be implemented by a child class")
+        raise NotImplementedError
 
     def _set_mss_product_type(self, version: int) -> None:
         """Set MSS product type and map corresponding bands"""
@@ -324,7 +323,7 @@ class LandsatProduct(OpticalProduct):
 
     def get_datetime(self, as_datetime: bool = False) -> Union[str, datetime]:
         """
-        Get the product's acquisition datetime, with format `YYYYMMDDTHHMMSS` <-> `%Y%m%dT%H%M%S`
+        Get the product's acquisition datetime, with format :code:`YYYYMMDDTHHMMSS` <-> :code:`%Y%m%dT%H%M%S`
 
         .. code-block:: python
 
@@ -345,11 +344,12 @@ class LandsatProduct(OpticalProduct):
         if self.datetime is None:
             mtd_data, _ = self._read_mtd()
 
-            try:
-                date = mtd_data.findtext(".//DATE_ACQUIRED")
-                hours = mtd_data.findtext(".//SCENE_CENTER_TIME").replace('"', "")[:-3]
-            except TypeError:
-                raise InvalidProductError("ACQUISITION_DATE not found in metadata!")
+            date = mtd_data.findtext(".//DATE_ACQUIRED")
+            hours = mtd_data.findtext(".//SCENE_CENTER_TIME").replace('"', "")[:-3]
+            if not date or not hours:
+                raise InvalidProductError(
+                    "DATE_ACQUIRED or SCENE_CENTER_TIME not found in metadata!"
+                )
 
             date = (
                 f"{datetime.strptime(date, '%Y-%m-%d').strftime('%Y%m%d')}"
@@ -373,19 +373,13 @@ class LandsatProduct(OpticalProduct):
         Returns:
             str: True name of the product (from metadata)
         """
-        if self.name is None:
-            # Get MTD XML file
-            root, _ = self.read_mtd()
+        # Get MTD XML file
+        root, _ = self.read_mtd()
 
-            # Open identifier
-            try:
-                name = root.findtext(".//LANDSAT_PRODUCT_ID").replace(
-                    '"', ""
-                )  # For txt files
-            except TypeError:
-                raise InvalidProductError("LANDSAT_PRODUCT_ID not found in metadata!")
-        else:
-            name = self.name
+        # Open identifier (replace for txt files)
+        name = root.findtext(".//LANDSAT_PRODUCT_ID").replace('"', "")
+        if not name:
+            raise InvalidProductError("LANDSAT_PRODUCT_ID not found in metadata!")
 
         return name
 
@@ -442,13 +436,11 @@ class LandsatProduct(OpticalProduct):
 
         return band_paths
 
-    def _read_mtd(
-        self, force_pd=False
-    ) -> Tuple[Union[pd.DataFrame, etree._Element], dict]:
+    def _read_mtd(self, force_pd=False) -> (etree._Element, dict):
         """
         Read Landsat metadata as:
 
-         - a `pandas.DataFrame` whatever its collection is (by default for collection 1)
+         - a :code:`pandas.DataFrame` whatever its collection is (by default for collection 1)
          - a XML root + its namespace if the product is retrieved from the 2nd collection (by default for collection 2)
 
         Args:
@@ -461,7 +453,7 @@ class LandsatProduct(OpticalProduct):
         try:
             # Open XML metadata
             mtd_from_path = "_MTL.xml"
-            mtd_archived = "_MTL\.xml"
+            mtd_archived = r"_MTL\.xml"
             mtd_data = self._read_mtd_xml(mtd_from_path, mtd_archived)
         except (InvalidProductError, FileNotFoundError):
             mtd_name = "_MTL.txt"
@@ -486,7 +478,7 @@ class LandsatProduct(OpticalProduct):
             # Parse
             mtd_data = pd.read_table(
                 mtd_path,
-                sep="\s=\s",
+                sep=r"\s=\s",
                 names=["NAME", "value"],
                 skipinitialspace=True,
                 engine="python",
@@ -513,7 +505,7 @@ class LandsatProduct(OpticalProduct):
             global_attr = [
                 E(str(attr), str(mtd_data[attr].iat[0])) for attr in attr_names
             ]
-            mtd = E.s3_global_attributes(*global_attr)
+            mtd = E.landsat_global_attributes(*global_attr)
             mtd_el = etree.fromstring(
                 etree.tostring(
                     mtd, pretty_print=True, xml_declaration=True, encoding="UTF-8"
@@ -591,28 +583,44 @@ class LandsatProduct(OpticalProduct):
 
                 # Get coeffs to convert DN to reflectance
                 try:
-                    c_mul = float(mtd_data.findtext(f".//{c_mul_str}"))
-                    c_add = float(mtd_data.findtext(f".//{c_add_str}"))
+                    c_mul = mtd_data.findtext(f".//{c_mul_str}")
+                    c_add = mtd_data.findtext(f".//{c_add_str}")
+
+                    # Manage some cases where the values are set to NULL
+                    if c_mul == "NULL":
+                        c_mul = 1.0
+                    else:
+                        c_mul = float(c_mul)
+                    if c_add == "NULL":
+                        c_add = 1.0
+                    else:
+                        c_add = float(c_add)
                 except TypeError:
-                    raise InvalidProductError("ACQUISITION_DATE not found in metadata!")
+                    if band in [obn.TIR_1, obn.TIR_2]:
+                        c_mul = 1.0
+                        c_add = 0.0
+                    else:
+                        raise InvalidProductError(
+                            f"Cannot find additive or multiplicative "
+                            f"rescaling factor for bands ({band.name}, "
+                            f"number {band_name}) in metadata"
+                        )
 
                 # Manage NULL values
                 try:
                     c_mul = float(c_mul)
                 except ValueError:
-                    c_mul = 1
+                    c_mul = 1.0
                 try:
                     c_add = float(c_add)
                 except ValueError:
-                    c_add = 0
+                    c_add = 0.0
 
                 # Compute the correct reflectance of the band and set no data to 0
                 band_xda = c_mul * band_xda + c_add  # Already in float
 
         return band_xda
 
-    # pylint: disable=R0913
-    # R0913: Too many arguments (6/5) (too-many-arguments)
     def _manage_invalid_pixels(
         self, band_arr: XDS_TYPE, band: obn, **kwargs
     ) -> XDS_TYPE:
@@ -651,7 +659,15 @@ class LandsatProduct(OpticalProduct):
         else:
             # https://www.usgs.gov/core-science-systems/nli/landsat/landsat-collection-2-quality-assessment-bands
             # SATURATED & OTHER PIXELS
-            band_nb = int(self.band_names[band])
+            try:
+                band_nb = int(self.band_names[band])
+            except ValueError:
+                if band in [obn.TIR_1, obn.TIR_2] and self.sat_id == Platform.L7.name:
+                    band_nb = 6
+                else:
+                    raise InvalidProductError(
+                        f"Cannot convert {self.band_names[band]} to integer."
+                    )
 
             # Bit ids
             sat_id = band_nb - 1  # Saturated pixel
@@ -673,6 +689,41 @@ class LandsatProduct(OpticalProduct):
 
         return self._set_nodata_mask(band_arr, mask)
 
+    def _manage_nodata(self, band_arr: XDS_TYPE, band: obn, **kwargs) -> XDS_TYPE:
+        """
+        Manage only nodata pixels
+
+        Args:
+            band_arr (XDS_TYPE): Band array
+            band (obn): Band name as an OpticalBandNames
+            kwargs: Other arguments used to load bands
+
+        Returns:
+            XDS_TYPE: Cleaned band array
+        """
+        # Open QA band
+        landsat_qa_path = self._get_path(self._radsat_id)
+        qa_arr = self._read_band(
+            landsat_qa_path,
+            size=(band_arr.rio.width, band_arr.rio.height),
+        ).data  # To np array
+
+        if self._collection == LandsatCollection.COL_1:
+            # https://www.usgs.gov/core-science-systems/nli/landsat/landsat-collection-1-level-1-quality-assessment-band
+            # Bit ids
+            nodata_id = 0  # Fill value
+            nodata = rasters.read_bit_array(qa_arr, nodata_id)
+        else:
+            # https://www.usgs.gov/core-science-systems/nli/landsat/landsat-collection-2-quality-assessment-bands
+            # If collection 2, nodata has to be found in pixel QA file
+            landsat_stat_path = self._get_path(self._pixel_quality_id)
+            pixel_arr = self._read_band(
+                landsat_stat_path, size=(band_arr.rio.width, band_arr.rio.height)
+            ).data
+            nodata = np.where(pixel_arr == 1, 1, 0)
+
+        return self._set_nodata_mask(band_arr, nodata)
+
     def _load_bands(
         self,
         bands: Union[list, BandNames],
@@ -701,7 +752,7 @@ class LandsatProduct(OpticalProduct):
 
         if resolution is None and size is not None:
             resolution = self._resolution_from_size(size)
-        band_paths = self.get_band_paths(bands, resolution=resolution)
+        band_paths = self.get_band_paths(bands, resolution=resolution, **kwargs)
 
         # Open bands and get array (resampled if needed)
         band_arrays = self._open_bands(
@@ -736,7 +787,6 @@ class LandsatProduct(OpticalProduct):
 
         return azimuth_angle, zenith_angle
 
-    @abstractmethod
     def _get_condensed_name(self) -> str:
         """
         Get products condensed name ({date}_Lx_{tile}_{product_type}).
@@ -876,8 +926,11 @@ class LandsatProduct(OpticalProduct):
 
             # Rename
             band_name = to_str(band)[0]
-            cloud.attrs["long_name"] = band_name
-            band_dict[band] = cloud.rename(band_name)
+
+            # Multi bands -> do not change long name
+            if band != RAW_CLOUDS:
+                cloud.attrs["long_name"] = band_name
+            band_dict[band] = cloud.rename(band_name).astype(np.float32)
 
         return band_dict
 
@@ -943,8 +996,11 @@ class LandsatProduct(OpticalProduct):
 
             # Rename
             band_name = to_str(band)[0]
-            cloud.attrs["long_name"] = band_name
-            band_dict[band] = cloud.rename(band_name)
+
+            # Multi bands -> do not change long name
+            if band != RAW_CLOUDS:
+                cloud.attrs["long_name"] = band_name
+            band_dict[band] = cloud.rename(band_name).astype(np.float32)
 
         return band_dict
 
@@ -1034,7 +1090,10 @@ class LandsatProduct(OpticalProduct):
 
             # Rename
             band_name = to_str(band)[0]
-            cloud.attrs["long_name"] = band_name
-            band_dict[band] = cloud.rename(band_name)
+
+            # Multi bands -> do not change long name
+            if band != RAW_CLOUDS:
+                cloud.attrs["long_name"] = band_name
+            band_dict[band] = cloud.rename(band_name).astype(np.float32)
 
         return band_dict
