@@ -43,8 +43,9 @@ from eoreader.bands import ALL_CLOUDS, CIRRUS, CLOUDS, RAW_CLOUDS, BandNames
 from eoreader.bands import OpticalBandNames as obn
 from eoreader.bands import to_str
 from eoreader.exceptions import InvalidProductError, InvalidTypeError
-from eoreader.keywords import SLSTR_RAD_ADJUST, SLSTR_STRIPE, SLSTR_VIEW
+from eoreader.keywords import CLEAN_OPTICAL, SLSTR_RAD_ADJUST, SLSTR_STRIPE, SLSTR_VIEW
 from eoreader.products import S3DataType, S3Instrument, S3Product, S3ProductType
+from eoreader.products.optical.optical_product import DEF_CLEAN_METHOD, CleanMethod
 from eoreader.reader import Platform
 from eoreader.utils import EOREADER_NAME
 
@@ -212,16 +213,17 @@ class S3SlstrProduct(S3Product):
         output_path: Union[str, CloudPath, Path] = None,
         remove_tmp: bool = False,
     ) -> None:
-
         """
         https://sentinels.copernicus.eu/web/sentinel/technical-guides/sentinel-3-slstr/level-1/observation-mode-desc
-        Note that the name of each netCDF file provides information about it's content.
+        Note that the name of each netCDF file provides information about its content.
+
         The suffix of each filename is associated with the selected grid:
-            "an" and "ao" refer to the 500 m grid, stripe A, respectively for nadir view (n) and oblique view (o)
-            "bn" and "bo" refer to the 500 m grid, stripe B
-            "in" and "io" refer to the 1 km grid
-            "fn" and "fo" refer to the F1 channel 1 km grid
-            "tx/n/o" refer to the tie-point grid for agnostic/nadir and oblique view
+
+        - "an" and "ao" refer to the 500 m grid, stripe A, respectively for nadir view (n) and oblique view (o)
+        - "bn" and "bo" refer to the 500 m grid, stripe B
+        - "in" and "io" refer to the 1 km grid
+        - "fn" and "fo" refer to the F1 channel 1 km grid
+        - "tx/n/o" refer to the tie-point grid for agnostic/nadir and oblique view
         """
         self._flags_file = None
         self._cloud_name = None
@@ -398,7 +400,7 @@ class S3SlstrProduct(S3Product):
 
         # Get the pre-processed path
         path = self._get_preprocessed_band_path(
-            pp_name, suffix=suffix, resolution=resolution
+            pp_name, suffix=suffix, resolution=resolution, writable=False
         )
 
         if not path.is_file():
@@ -587,6 +589,7 @@ class S3SlstrProduct(S3Product):
     #     https://sentinel.esa.int/web/sentinel/technical-guides/sentinel-3-slstr/instrument/measured-spectral-response-function-data
     #
     #     In https://sentinel.esa.int/documents/247904/4598085/Sentinel-3-SLSTR-Land-Handbook.pdf/bee342eb-40d4-9b31-babb-8bea2748264a
+    #
     #     Args:
     #         band_arr (xr.DataArray): Band array
     #         band (obn): Optical Band
@@ -762,8 +765,6 @@ class S3SlstrProduct(S3Product):
 
         return e0
 
-    # pylint: disable=R0913
-    # R0913: Too many arguments (6/5) (too-many-arguments)
     def _manage_invalid_pixels(
         self, band_arr: XDS_TYPE, band: obn, **kwargs
     ) -> XDS_TYPE:
@@ -917,8 +918,11 @@ class S3SlstrProduct(S3Product):
 
                 # Rename
                 band_name = to_str(band)[0]
-                cloud.attrs["long_name"] = band_name
-                band_dict[band] = cloud.rename(band_name)
+
+                # Multi bands -> do not change long name
+                if band != RAW_CLOUDS:
+                    cloud.attrs["long_name"] = band_name
+                band_dict[band] = cloud.rename(band_name).astype(np.float32)
 
         return band_dict
 
@@ -1000,9 +1004,13 @@ class S3SlstrProduct(S3Product):
         Returns:
             Union[CloudPath, Path]: Clean band path
         """
+        cleaning_method = CleanMethod.from_value(
+            kwargs.get(CLEAN_OPTICAL, DEF_CLEAN_METHOD)
+        )
+
         suffix = self._get_suffix(band, **kwargs)
         res_str = self._resolution_to_str(resolution)
 
         return self._get_band_folder(writable).joinpath(
-            f"{self.condensed_name}_{band.name}_{suffix}_{res_str.replace('.', '-')}_clean.tif",
+            f"{self.condensed_name}_{band.name}_{suffix}_{res_str.replace('.', '-')}_{cleaning_method.value}.tif",
         )
