@@ -38,7 +38,6 @@ import xarray as xr
 from affine import Affine
 from cloudpathlib import AnyPath, CloudPath
 from lxml import etree, html
-from rasterio import crs as riocrs
 from rasterio import transform, warp
 from rasterio.crs import CRS
 from rasterio.enums import Resampling
@@ -284,7 +283,7 @@ class Product:
 
     @cached_property
     @abstractmethod
-    def crs(self) -> riocrs.CRS:
+    def crs(self) -> CRS:
         """
         Get UTM projection of the tile
 
@@ -1197,7 +1196,7 @@ class Product:
                         resolution = self.resolution
 
                     bounds = transform.array_bounds(def_h, def_w, def_tr)
-                    dst_tr, out_w, out_h = rasterio.warp.calculate_default_transform(
+                    dst_tr, out_w, out_h = warp.calculate_default_transform(
                         def_crs,
                         self.crs,
                         def_w,
@@ -1417,6 +1416,9 @@ class Product:
         if not isinstance(bands, list):
             bands = [bands]
 
+        # Ensure the bands are not in strings (otherwise will bug in Dataset conversion)
+        bands = to_band(bands)
+
         if not resolution and not size:
             resolution = self.resolution
 
@@ -1658,3 +1660,36 @@ class Product:
             res_str = _res_to_str(self.resolution)
 
         return res_str
+
+    def to_repr(self) -> list:
+        """
+        Returns a representation of the product as a list
+
+        Returns:
+            list: Representation of the product
+        """
+        band_repr = "\n".join(
+            [
+                f"\t\t{band.value}: {nb}"
+                for band, nb in self.band_names.items()
+                if nb is not None
+            ]
+        )
+        return [
+            f"EOReader {self.__class__.__name__}",
+            "Attributes:",
+            f"\tcondensed_name: {self.condensed_name}",
+            f"\tname: {self.name}",
+            f"\tpath: {self.path}",
+            f"\tplatform: {self.platform if isinstance(self.platform, str) else self.platform.value}",
+            f"\tsensor type: {self.sensor_type if isinstance(self.sensor_type, str) else self.sensor_type.value}",
+            f"\tproduct type: {self.product_type if isinstance(self.product_type, str) else self.product_type.value}",
+            f"\tdefault resolution: {self.resolution}",
+            f"\tacquisition datetime: {self.get_datetime(as_datetime=True).isoformat()}",
+            f"\tband mapping:\n{band_repr}",
+            f"\ttile name: {self.tile_name if self.tile_name is not None else 'N/A'}",
+            f"\tneeds_extraction: {self.needs_extraction}",
+        ]
+
+    def __repr__(self):
+        return "\n".join(self.to_repr())
