@@ -94,28 +94,14 @@ class IceyeProduct(SarProduct):
         <here](https://www.iceye.com/hubfs/Downloadables/ICEYE_SAR_Product_Guide_2021_V4.0.pdf>`_
         for more information (table B.3).
         """
-        # For complex data, set regular ground range resolution provided by the constructor
-        if self.product_type == IceyeProductType.SLC:
-            if self.sensor_mode == IceyeSensorMode.SM:
-                def_res = 2.5
-            elif self.sensor_mode == IceyeSensorMode.SL:
-                def_res = 0.5
-            elif self.sensor_mode == IceyeSensorMode.SC:
-                def_res = 6.0
-            else:
-                raise InvalidProductError(f"Unknown sensor mode: {self.sensor_mode}")
+        if self.sensor_mode == IceyeSensorMode.SM:
+            def_res = 3.0
+        elif self.sensor_mode == IceyeSensorMode.SL:
+            def_res = 1.0
+        elif self.sensor_mode == IceyeSensorMode.SC:
+            def_res = 15.0
         else:
-            # Read metadata for default resolution
-            try:
-                root, nsmap = self.read_mtd()
-
-                # Some ICEYE product metadata has a namespace some don't
-                namespace = nsmap.get(None, "")
-
-                def_res = float(root.findtext(f".//{namespace}range_spacing"))
-            except (InvalidProductError, TypeError):
-                raise InvalidProductError("range_spacing not found in metadata!")
-
+            raise InvalidProductError(f"Unknown sensor mode: {self.sensor_mode}")
         return def_res
 
     def _pre_init(self) -> None:
@@ -124,6 +110,7 @@ class IceyeProduct(SarProduct):
         (setting needs_extraction and so on)
         """
         # Private attributes
+        # TODO: Allow to use SLC data ? Or SLC and GRD are always together ?
         self._raw_band_regex = "*ICEYE*GRD*.tif"
         self._band_folder = self.path
         self._snap_path = str(next(self.path.glob("*ICEYE*GRD*.xml")).name)
@@ -183,9 +170,8 @@ class IceyeProduct(SarProduct):
         namespace = nsmap.get(None, "")
 
         # Open identifier
-        try:
-            prod_type = root.findtext(f".//{namespace}product_level")
-        except TypeError:
+        prod_type = root.findtext(f".//{namespace}product_level")
+        if not prod_type:
             raise InvalidProductError("mode not found in metadata!")
 
         self.product_type = IceyeProductType.from_value(prod_type)
@@ -216,9 +202,8 @@ class IceyeProduct(SarProduct):
         namespace = nsmap.get(None, "")
 
         # Open identifier
-        try:
-            imaging_mode = root.findtext(f".//{namespace}acquisition_mode")
-        except TypeError:
+        imaging_mode = root.findtext(f".//{namespace}acquisition_mode")
+        if not imaging_mode:
             raise InvalidProductError("imagingMode not found in metadata!")
 
         # Get sensor mode
@@ -229,7 +214,7 @@ class IceyeProduct(SarProduct):
 
     def get_datetime(self, as_datetime: bool = False) -> Union[str, datetime]:
         """
-        Get the product's acquisition datetime, with format `YYYYMMDDTHHMMSS` <-> `%Y%m%dT%H%M%S`
+        Get the product's acquisition datetime, with format :code:`YYYYMMDDTHHMMSS` <-> :code:`%Y%m%dT%H%M%S`
 
         .. code-block:: python
 
@@ -255,9 +240,8 @@ class IceyeProduct(SarProduct):
             namespace = nsmap.get(None, "")
 
             # Open identifier
-            try:
-                acq_date = root.findtext(f".//{namespace}acquisition_start_utc")
-            except TypeError:
+            acq_date = root.findtext(f".//{namespace}acquisition_start_utc")
+            if not acq_date:
                 raise InvalidProductError(
                     "acquisition_start_utc not found in metadata!"
                 )
@@ -279,20 +263,16 @@ class IceyeProduct(SarProduct):
         Returns:
             str: True name of the product (from metadata)
         """
-        if self.name is None:
-            # Get MTD XML file
-            root, nsmap = self.read_mtd()
+        # Get MTD XML file
+        root, nsmap = self.read_mtd()
 
-            # Some ICEYE product metadata has a namespace some don't
-            namespace = nsmap.get(None, "")
+        # Some ICEYE product metadata has a namespace some don't
+        namespace = nsmap.get(None, "")
 
-            # Open identifier
-            try:
-                name = root.findtext(f".//{namespace}product_name")
-            except TypeError:
-                raise InvalidProductError("product_name not found in metadata!")
-        else:
-            name = self.name
+        # Open identifier
+        name = root.findtext(f".//{namespace}product_name")
+        if not name:
+            raise InvalidProductError("product_name not found in metadata!")
 
         return name
 
@@ -327,7 +307,7 @@ class IceyeProduct(SarProduct):
         band_paths = {}
         try:
             band_paths[sbn.VV] = files.get_file_in_dir(
-                self._band_folder, self._raw_band_regex, exact_name=True, get_list=True
+                self._band_folder, self._raw_band_regex, exact_name=True, get_list=False
             )
         except FileNotFoundError:
             raise InvalidProductError(
