@@ -178,74 +178,69 @@ class Rs2Product(SarProduct):
         """
         Set product default resolution (in meters)
         """
-        def_res = None
-        # For complex data, set regular ground range resolution provided by the constructor
-        # Missing Ocean Surveillance and Ship Detection because the values are contextual
-        if self.product_type == Rs2ProductType.SLC:
-            # -------------------------------------------------------------
-            # Selective Single or Dual Polarization
-            # Transmit H and/or V, receive H and/or V
-            # F = "Fine", WF = "Wide Fine"
-            if self.sensor_mode in [Rs2SensorMode.F, Rs2SensorMode.WF]:
-                def_res = 8.0
-            # S = "Standard", W = "Wide"
-            elif self.sensor_mode == [Rs2SensorMode.S, Rs2SensorMode.W]:
-                def_res = 25.0
-            # SCN = "ScanSAR Narrow"
-            elif self.sensor_mode == Rs2SensorMode.SCN:
-                def_res = 50.0
-            # SCW = "ScanSAR Wide"
-            elif self.sensor_mode == Rs2SensorMode.SCW:
-                def_res = 100.0
+        # -------------------------------------------------------------
+        # Selective Single or Dual Polarization
+        # Transmit H and/or V, receive H and/or V
+        # F = "Fine", WF = "Wide Fine"
+        if self.sensor_mode in [Rs2SensorMode.F, Rs2SensorMode.WF]:
+            def_res = 8.0
+        # S = "Standard", W = "Wide"
+        elif self.sensor_mode in [Rs2SensorMode.S, Rs2SensorMode.W]:
+            def_res = 25.0
+        # SCN = "ScanSAR Narrow"
+        elif self.sensor_mode == Rs2SensorMode.SCN:
+            def_res = 50.0
+        # SCW = "ScanSAR Wide"
+        elif self.sensor_mode == Rs2SensorMode.SCW:
+            def_res = 100.0
 
-            # -------------------------------------------------------------
-            # Polarimetric
-            # Transmit H and V on alternate pulses /
-            # receive H and V on any pulse
-            # FQ = "Fine Quad-Pol", WFQ = "Wide Fine Quad-Pol"
-            elif self.sensor_mode == [Rs2SensorMode.FQ, Rs2SensorMode.WFQ]:
-                def_res = 12.0
-            # SQ = "Standard Quad-Pol", "Wide Standard Quad-Pol"
-            elif self.sensor_mode == [Rs2SensorMode.SQ, Rs2SensorMode.WSQ]:
-                def_res = 25.0
+        # -------------------------------------------------------------
+        # Polarimetric
+        # Transmit H and V on alternate pulses /
+        # receive H and V on any pulse
+        # FQ = "Fine Quad-Pol", WFQ = "Wide Fine Quad-Pol"
+        elif self.sensor_mode in [Rs2SensorMode.FQ, Rs2SensorMode.WFQ]:
+            def_res = 12.0
+        # SQ = "Standard Quad-Pol", "Wide Standard Quad-Pol"
+        elif self.sensor_mode in [Rs2SensorMode.SQ, Rs2SensorMode.WSQ]:
+            def_res = 25.0
 
-            # -------------------------------------------------------------
-            # Single Polarization HH
-            # Transmit H, receive H
-            # EH = "Extended High"
-            elif self.sensor_mode == Rs2SensorMode.EH:
-                def_res = 25.0
-            # EL = "Extended Low"
-            elif self.sensor_mode == Rs2SensorMode.EL:
-                def_res = 60.0
+        # -------------------------------------------------------------
+        # Single Polarization HH
+        # Transmit H, receive H
+        # EH = "Extended High"
+        elif self.sensor_mode == Rs2SensorMode.EH:
+            def_res = 25.0
+        # EL = "Extended Low"
+        elif self.sensor_mode == Rs2SensorMode.EL:
+            def_res = 60.0
 
-            # -------------------------------------------------------------
-            # Selective Single Polarization
-            # Transmit H or V, receive H or V
-            # EH = "Extended High"
-            # SLA = "Spotlight"
-            elif self.sensor_mode == Rs2SensorMode.SLA:
-                def_res = 1.0
-            # U = "Ultra-Fine", WU = "Wide Ultra-Fine"
-            elif self.sensor_mode == [Rs2SensorMode.U, Rs2SensorMode.WU]:
-                def_res = 3.0
-            # XF = "Extra-Fine"
-            elif self.sensor_mode == Rs2SensorMode.XF:
-                def_res = 5.0
-            # MF = "Multi-Look Fine", WMF = "Wide Multi-Look Fine"
-            elif self.sensor_mode == [Rs2SensorMode.MF, Rs2SensorMode.WMF]:
-                def_res = 8.0
+        # -------------------------------------------------------------
+        # Selective Single Polarization
+        # Transmit H or V, receive H or V
+        # EH = "Extended High"
+        # SLA = "Spotlight"
+        elif self.sensor_mode == Rs2SensorMode.SLA:
+            def_res = 1.0
+        # U = "Ultra-Fine", WU = "Wide Ultra-Fine"
+        elif self.sensor_mode in [Rs2SensorMode.U, Rs2SensorMode.WU]:
+            def_res = 3.0
+        # XF = "Extra-Fine"
+        elif self.sensor_mode == Rs2SensorMode.XF:
+            def_res = 5.0
+        # MF = "Multi-Look Fine", WMF = "Wide Multi-Look Fine"
+        elif self.sensor_mode in [Rs2SensorMode.MF, Rs2SensorMode.WMF]:
+            def_res = 8.0
 
-        if not def_res:
-            # Read metadata
-            try:
-                root, nsmap = self.read_mtd()
-                namespace = nsmap[None]
-                def_res = float(root.findtext(f".//{namespace}sampledPixelSpacing"))
-            except (InvalidProductError, TypeError):
-                raise InvalidProductError(
-                    "sampledPixelSpacing or rowSpacing not found in metadata!"
-                )
+        # -------------------------------------------------------------
+        # Ocean surveillance and detection of vessels
+        elif self.sensor_mode == Rs2SensorMode.OSVN:
+            def_res = 50.0
+
+        elif self.sensor_mode == Rs2SensorMode.DVWF:
+            def_res = 35.0
+        else:
+            raise InvalidProductError(f"Unknown sensor mode: {self.sensor_mode}")
 
         return def_res
 
@@ -259,8 +254,17 @@ class Rs2Product(SarProduct):
         self._band_folder = self.path
         self._snap_path = ""
 
-        # Zipped and SNAP can process its archive
-        self.needs_extraction = False
+        # SNAP can process non-complex archive
+        root, nsmap = self.read_mtd()
+        namespace = nsmap[None]
+
+        # Open identifier
+        prod_type = root.findtext(f".//{namespace}productType")
+        if not prod_type:
+            raise InvalidProductError("productType not found in metadata!")
+
+        self.product_type = Rs2ProductType.from_value(prod_type)
+        self.needs_extraction = self.product_type == Rs2ProductType.SLC
 
         # Post init done by the super class
         super()._pre_init()
@@ -296,7 +300,7 @@ class Rs2Product(SarProduct):
         # Open extent KML file
         try:
             if self.is_archived:
-                product_kml = vectors.read(self.path, archive_regex=".*product\.kml")
+                product_kml = vectors.read(self.path, archive_regex=r".*product\.kml")
             else:
                 extent_file = next(self.path.glob("*product.kml"))
                 product_kml = vectors.read(extent_file)
@@ -313,30 +317,14 @@ class Rs2Product(SarProduct):
 
     def _set_product_type(self) -> None:
         """Set products type"""
-        # Get MTD XML file
-        root, nsmap = self.read_mtd()
-        namespace = nsmap[None]
-
-        # Open identifier
-        try:
-            prod_type = root.findtext(f".//{namespace}productType")
-        except TypeError:
-            raise InvalidProductError("mode not found in metadata!")
-
-        self.product_type = Rs2ProductType.from_value(prod_type)
-
-        if self.product_type == Rs2ProductType.SGF:
-            self.sar_prod_type = SarProductType.GDRG
-        elif self.product_type == Rs2ProductType.SLC:
+        if self.product_type == Rs2ProductType.SLC:
             self.sar_prod_type = SarProductType.CPLX
         else:
-            raise NotImplementedError(
-                f"{self.product_type.value} product type is not available for {self.name}"
-            )
+            self.sar_prod_type = SarProductType.GDRG
 
-        if self.product_type != Rs2ProductType.SGF:
+        if self.product_type not in [Rs2ProductType.SGF, Rs2ProductType.SLC]:
             LOGGER.warning(
-                "Other products type than SGF has not been tested for %s data. "
+                "Other product types than SGF or SLC haven't been tested for %s data. "
                 "Use it at your own risks !",
                 self.platform.value,
             )
@@ -367,7 +355,7 @@ class Rs2Product(SarProduct):
 
     def get_datetime(self, as_datetime: bool = False) -> Union[str, datetime]:
         """
-        Get the product's acquisition datetime, with format `YYYYMMDDTHHMMSS` <-> `%Y%m%dT%H%M%S`
+        Get the product's acquisition datetime, with format :code:`YYYYMMDDTHHMMSS` <-> :code:`%Y%m%dT%H%M%S`
 
         .. code-block:: python
 
@@ -391,9 +379,8 @@ class Rs2Product(SarProduct):
             namespace = nsmap[None]
 
             # Open identifier
-            try:
-                acq_date = root.findtext(f".//{namespace}rawDataStartTime")
-            except TypeError:
+            acq_date = root.findtext(f".//{namespace}rawDataStartTime")
+            if not acq_date:
                 raise InvalidProductError("rawDataStartTime not found in metadata!")
 
             # Convert to datetime
@@ -413,20 +400,16 @@ class Rs2Product(SarProduct):
         Returns:
             str: True name of the product (from metadata)
         """
-        if self.name is None:
-            name = self.filename
+        name = self.filename
 
-            # Test filename
-            reader = Reader()
-            if not reader.valid_name(name, self._get_platform()):
-                LOGGER.warning(
-                    "This RADARSAT-2 filename is not valid. "
-                    "However RADARSAT-2 files do not provide anywhere the true name of the product."
-                    "Use it with caution."
-                )
-
-        else:
-            name = self.name
+        # Test filename
+        reader = Reader()
+        if not reader.valid_name(name, self._get_platform()):
+            LOGGER.warning(
+                "This RADARSAT-2 filename is not valid. "
+                "However RADARSAT-2 files do not provide anywhere the true name of the product. "
+                "Use it with caution."
+            )
 
         return name
 
@@ -448,6 +431,6 @@ class Rs2Product(SarProduct):
             (etree._Element, dict): Metadata XML root and its namespace
         """
         mtd_from_path = "product.xml"
-        mtd_archived = "product\.xml"
+        mtd_archived = r"product\.xml"
 
         return self._read_mtd_xml(mtd_from_path, mtd_archived)
