@@ -54,8 +54,10 @@ class S1ProductType(ListEnum):
 
     SLC = "SLC"
     """Single Look Complex (SLC, lvl 1)"""
+
     GRD = "GRD"
     """Ground Range Detected (GRD, lvl 1, phase lost)"""
+
     OCN = "OCN"
     """Ocean products (lvl 2): **not used by EOReader**"""
 
@@ -99,30 +101,16 @@ class S1Product(SarProduct):
         <here](https://sentinel.esa.int/web/sentinel/user-guides/sentinel-1-sar/resolutions/level-1-ground-range-detected>`_
         for more information
         """
-        def_res = None
-        # For complex data, set regular ground range resolution provided by the constructor
-        # For Sentinel data, use the best resolution available
-        if self.product_type == S1ProductType.SLC:
-            if self.sensor_mode == S1SensorMode.SM:
-                def_res = 3.5  # Full Resolution GRD
-            elif self.sensor_mode == S1SensorMode.IW:
-                def_res = 10.0  # High  Resolution GRD
-            elif self.sensor_mode == S1SensorMode.EW:
-                def_res = 25.0  # High  Resolution GRD
-            elif self.sensor_mode == S1SensorMode.WV:
-                def_res = 25.0  # Medium Resolution GRD
-
-        if not def_res:
-            root, _ = self.read_mtd()
-
-            # Read metadata
-            try:
-                def_res = float(root.findtext(".//rangePixelSpacing"))
-            except TypeError:
-                raise InvalidProductError(
-                    "rangePixelSpacing or rowSpacing not found in metadata!"
-                )
-
+        if self.sensor_mode == S1SensorMode.SM:
+            def_res = 9.0  # Full Resolution GRD
+        elif self.sensor_mode == S1SensorMode.IW:
+            def_res = 20.0  # High  Resolution GRD
+        elif self.sensor_mode == S1SensorMode.EW:
+            def_res = 50.0  # High  Resolution GRD
+        elif self.sensor_mode == S1SensorMode.WV:
+            def_res = 52.0  # Medium Resolution GRD
+        else:
+            raise InvalidProductError(f"Unknown sensor mode: {self.sensor_mode}")
         return def_res
 
     def _pre_init(self) -> None:
@@ -211,16 +199,15 @@ class S1Product(SarProduct):
         root, _ = self.read_mtd()
 
         # Open identifier
-        try:
-            prod_type = root.findtext(".//productType")
-        except TypeError:
+        prod_type = root.findtext(".//productType")
+        if not prod_type:
             raise InvalidProductError("mode not found in metadata!")
 
         self.product_type = S1ProductType.from_value(prod_type)
 
         if self.product_type == S1ProductType.GRD:
             self.sar_prod_type = SarProductType.GDRG
-        elif self.product_type in S1ProductType.SLC:
+        elif self.product_type == S1ProductType.SLC:
             self.sar_prod_type = SarProductType.CPLX
         else:
             raise NotImplementedError(
@@ -235,9 +222,8 @@ class S1Product(SarProduct):
         root, _ = self.read_mtd()
 
         # Open identifier
-        try:
-            mode = root.findtext(".//mode")
-        except TypeError:
+        mode = root.findtext(".//mode")
+        if not mode:
             raise InvalidProductError("mode not found in metadata!")
 
         # Get sensor mode
@@ -255,7 +241,7 @@ class S1Product(SarProduct):
 
     def get_datetime(self, as_datetime: bool = False) -> Union[str, datetime]:
         """
-        Get the product's acquisition datetime, with format `YYYYMMDDTHHMMSS` <-> `%Y%m%dT%H%M%S`
+        Get the product's acquisition datetime, with format :code:`YYYYMMDDTHHMMSS` <-> :code:`%Y%m%dT%H%M%S`
 
         .. code-block:: python
 
@@ -278,9 +264,8 @@ class S1Product(SarProduct):
             root, _ = self.read_mtd()
 
             # Open identifier
-            try:
-                acq_date = root.findtext(".//startTime")
-            except TypeError:
+            acq_date = root.findtext(".//startTime")
+            if not acq_date:
                 raise InvalidProductError("startTime not found in metadata!")
 
             # Convert to datetime
@@ -300,27 +285,23 @@ class S1Product(SarProduct):
         Returns:
             str: True name of the product (from metadata)
         """
-        if self.name is None:
-            # The name is not in the classic metadata, but can be found in the manifest
-            try:
-                mtd_from_path = "preview/product-preview.html"
-                mtd_archived = "preview.*product-preview\.html"
+        # The name is not in the classic metadata, but can be found in the manifest
+        try:
+            mtd_from_path = "preview/product-preview.html"
+            mtd_archived = r"preview.*product-preview\.html"
 
-                root = self._read_mtd_html(mtd_from_path, mtd_archived)
+            root = self._read_mtd_html(mtd_from_path, mtd_archived)
 
-                # Open identifier
-                try:
-                    name = root.findtext(".//head/title")
-                except TypeError:
-                    raise InvalidProductError("title not found in metadata!")
+            # Open identifier
+            name = root.findtext(".//head/title")
+            if not name:
+                raise InvalidProductError("title not found in metadata!")
 
-            except InvalidProductError:
-                LOGGER.warning(
-                    "product-preview.html not found in the product, the name will be the filename"
-                )
-                name = self.filename
-        else:
-            name = self.name
+        except InvalidProductError:
+            LOGGER.warning(
+                "product-preview.html not found in the product, the name will be the filename"
+            )
+            name = self.filename
 
         return name
 
@@ -343,6 +324,6 @@ class S1Product(SarProduct):
         mtd_from_path = "annotation/*.xml"
 
         # When archived, other XML (in calibration folder) can be found
-        mtd_archived = "annotation/(?!rfi)(?!cal)(?!noise).*\.xml"
+        mtd_archived = r"annotation/(?!rfi)(?!cal)(?!noise).*\.xml"
 
         return self._read_mtd_xml(mtd_from_path, mtd_archived)
