@@ -22,13 +22,17 @@ from pathlib import Path
 from typing import Union
 
 import numpy as np
+import pandas as pd
 import xarray as xr
 from cloudpathlib import AnyPath, CloudPath
+from lxml import etree
 from rasterio.control import GroundControlPoint
 from rasterio.enums import Resampling
+from rasterio.rpc import RPC
 from sertit import rasters
 
 from eoreader.env_vars import USE_DASK
+from eoreader.keywords import prune_keywords
 
 EOREADER_NAME = "eoreader"
 DATETIME_FMT = "%Y%m%dT%H%M%S"
@@ -123,7 +127,7 @@ def read(
     **kwargs,
 ) -> xr.DataArray:
     """
-    Overload of `sertit.rasters.read()` managing  DASK in EOReader's way.
+    Overload of :code:`sertit.rasters.read()` managing  DASK in EOReader's way.
 
     .. code-block:: python
 
@@ -160,29 +164,30 @@ def read(
         masked=masked,
         indexes=indexes,
         chunks=chunks,
-        **kwargs,
+        **prune_keywords(**kwargs),
     )
 
 
 def write(xds: xr.DataArray, path: Union[str, CloudPath, Path], **kwargs) -> None:
     """
-    Overload of `sertit.rasters.write()` managing DASK in EOReader's way.
+    Overload of :code:`sertit.rasters.write()` managing DASK in EOReader's way.
 
-    ```python
-    >>> raster_path = "path/to/raster.tif"
-    >>> raster_out = "path/to/out.tif"
+    .. code-block:: python
 
-    >>> # Read raster
-    >>> xds = read(raster_path)
+        >>> raster_path = "path/to/raster.tif"
+        >>> raster_out = "path/to/out.tif"
+
+        >>> # Read raster
+        >>> xds = read(raster_path)
+
+        >>> # Rewrite it
+        >>> write(xds, raster_out)
 
-    >>> # Rewrite it
-    >>> write(xds, raster_out)
-    ```
 
     Args:
         xds (xr.DataArray): Path to the raster or a rasterio dataset or a xarray
         path (Union[str, CloudPath, Path]): Path where to save it (directories should be existing)
-        **kwargs: Overloading metadata, ie `nodata=255` or `dtype=np.uint8`
+        **kwargs: Overloading metadata, ie :code:`nodata=255` or :code:`dtype=np.uint8`
     """
     if use_dask():
         from distributed import Lock, get_client
@@ -191,12 +196,28 @@ def write(xds: xr.DataArray, path: Union[str, CloudPath, Path], **kwargs) -> Non
     else:
         lock = None
 
-    return rasters.write(xds, path=path, lock=lock, **kwargs)
+    # Reset the long name as a list to write it down
+    previous_long_name = xds.attrs.get("long_name")
+    if previous_long_name and xds.rio.count > 1:
+        try:
+            xds.attrs["long_name"] = xds.attrs.get(
+                "long_name", xds.attrs.get("name", "")
+            ).split(" ")
+        except AttributeError:
+            pass
+
+    # Write
+    rasters.write(xds, path=path, lock=lock, **prune_keywords(**kwargs))
+
+    # Set back the previous long name
+    if previous_long_name and xds.rio.count > 1:
+        xds.attrs["long_name"] = previous_long_name
 
 
 def create_gcps(lon: xr.DataArray, lat: xr.DataArray, alt: xr.DataArray) -> list:
     """
-    Create GCPs from an array of longitude, latitude and altitude (based on Sentinel-3 geocoding)
+    Create GCPs from an array of longitude, latitude and altitude (based on Sentinel-3 geocoding).
+
     Args:
         lon (xr.DataArray): Longitude array
         lat (xr.DataArray): Latitude array
@@ -238,3 +259,92 @@ def create_gcps(lon: xr.DataArray, lat: xr.DataArray, alt: xr.DataArray) -> list
                 gcp_id += 1
 
     return gcps
+
+
+def quick_xml_to_dict(element: etree._Element) -> tuple:
+    """
+    Convert a lxml root to a nested dict (quick and dirty)
+
+    https://lxml.de/FAQ.html#how-can-i-map-an-xml-tree-into-a-dict-of-dicts:
+
+
+        How can I map an XML tree into a dict of dicts?
+
+        Note that this beautiful quick-and-dirty converter expects children to have unique tag names and will silently
+        overwrite any data that was contained in preceding siblings with the same name.
+        For any real-world application of xml-to-dict conversion, you would better write your own,
+        longer version of this.
+
+    Args:
+        element (etree._Element): Element to convert into a dict
+
+    Returns:
+        : XML as a nested dict
+
+    """
+    return element.tag, dict(map(quick_xml_to_dict, element)) or element.text
+
+
+def open_rpc_file(path: Union[CloudPath, Path]) -> RPC:
+    """
+    Create a rasterio RPC object from a :code:`.rpc` file.
+    Used for Vision-1 product
+
+    Args:
+        path: Path of the RPC file
+
+    Returns:
+        RPC: RPC object
+    """
+
+    def to_float(pd_table, field) -> float:
+        pd_field = pd_table.T[field]
+        val = None
+        for val in pd_field.values[0].split(" "):
+            if val:
+                break
+        return float(val)
+
+    def to_list(pd_table, field) -> list:
+        pd_list = pd_table[pd_table.index.str.contains(field)].values
+        return [float(val[0]) for val in pd_list]
+
+    try:
+        rpcs_file = pd.read_csv(
+            path, delimiter=":", names=["name", "value"], index_col=0
+        )
+
+        height_off = to_float(rpcs_file, "HEIGHT_OFF")
+        height_scale = to_float(rpcs_file, "HEIGHT_SCALE")
+        lat_off = to_float(rpcs_file, "LAT_OFF")
+        lat_scale = to_float(rpcs_file, "LAT_SCALE")
+        line_den_coeff = to_list(rpcs_file, "LINE_DEN_COEFF")
+        line_num_coeff = to_list(rpcs_file, "LINE_NUM_COEFF")
+        line_off = to_float(rpcs_file, "LINE_OFF")
+        line_scale = to_float(rpcs_file, "LINE_SCALE")
+        long_off = to_float(rpcs_file, "LONG_OFF")
+        long_scale = to_float(rpcs_file, "LONG_SCALE")
+        samp_den_coeff = to_list(rpcs_file, "SAMP_DEN_COEFF")
+        samp_num_coeff = to_list(rpcs_file, "SAMP_NUM_COEFF")
+        samp_off = to_float(rpcs_file, "SAMP_OFF")
+        samp_scale = to_float(rpcs_file, "SAMP_SCALE")
+        return RPC(
+            height_off,
+            height_scale,
+            lat_off,
+            lat_scale,
+            line_den_coeff,
+            line_num_coeff,
+            line_off,
+            line_scale,
+            long_off,
+            long_scale,
+            samp_den_coeff,
+            samp_num_coeff,
+            samp_off,
+            samp_scale,
+            err_bias=None,
+            err_rand=None,
+        )
+    except KeyError as msg:
+        raise KeyError(f"Invalid RPC file, missing key: {msg}")
